@@ -2079,7 +2079,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "RecommenderClient":
         return self
 
     def __exit__(self, type, value, traceback):
